fixnum_csq library

Signed 32- and 64-bit integer support.

The integer implementations in this library are designed to work identically whether executed on the Dart VM or compiled to JavaScript or Wasm.

Classes

Int32
An immutable 32-bit signed integer, in the range [-2^31, 2^31 - 1]. Arithmetic operations may overflow in order to maintain this range.
Int64
An immutable 64-bit signed integer, in the range [-2^63, 2^63 - 1]. Arithmetic operations may overflow in order to maintain this range.
IntX
A fixed-precision integer.